@@ -55,7 +55,7 @@ class GemText:
         return result
 
     def string(self):
-        result = StringIO
+        result = StringIO()
         for line in self.lines:
             result.write(line.string())
         return result.getvalue()
@@ -66,7 +66,6 @@ def parseGemText(gemtext = ""):
     result = GemText()
 
     pre = False
-    firstLevel1Heading = ""
     for line in lines:
         line = line.strip()
 
